﻿"use strict";
var app = angular.module('app', ['ngFileUpload']);

//------------------------
//      NG NUMERIC      //
//------------------------
app.directive('ngNumeric', ['$filter', '$interpolate', function ($filter, $interpolate) {
    var FLOAT_REGEXP_1 = /^\$?\d+(.\d{3})*(\,\d*)?$/; //Numbers like: 1.123,56
    var FLOAT_REGEXP_2 = /^\$?\d+(,\d{3})*(\.\d*)?$/; //Numbers like: 1,123.56
    var nDecimal = 0;
    var decimalPlaces = function (num) {
        var match = ('' + num).match(/(?:\.(\d+))?(?:[eE]([+-]?\d+))?$/);
        if (!match) return 0;
        return Math.max(0, (match[1] ? match[1].length : 0) - (match[2] ? +match[2] : 0));
    }
    var formatNumber = function (_num, d) {
        if (d == undefined) {
            if (nDecimal == undefined) {
                d = decimalPlaces(_num);
            } else {
                d = nDecimal;
            }
        }
        return (isNaN(d) || d === undefined) ? $filter('number')(_num) : $filter('number')(_num, d);
    };
    var getNumber = function (_num, d) {
        if (d == undefined) {
            if (nDecimal == undefined) {
                d = decimalPlaces(_num);
            } else {
                d = nDecimal;
            }
        }
        if (!isNaN(_num))
            _num = _num.toString();

        if (FLOAT_REGEXP_2.test(_num)) {
            var num = parseFloat(_num.replace(/,/g, ''));
        } else if (FLOAT_REGEXP_1.test(_num)) {
            var num = parseFloat(_num.replace(/./g, '').replace(/,/g, '.'));
        }
        else {
            var num = 0;
        }

        if (!isNaN(d) || d !== undefined && d !== decimalPlaces(_num))
            num = num.toFixed(d);

        return num;
    };
    var disabledContextMenu = function (event) {
        //console.info('event>> ', event);
        var e = event || window.event;
        e.preventDefault && e.preventDefault();
        e.stopPropagation && e.stopPropagation();
        e.cancelBubble = true;
        e.returnValue = false;
        return false;
    }

    return {
        require: 'ngModel', scope: false, restrict: 'A',
        link: function (scope, elm, attrs, ctrl) {
            attrs.$observe('decimal', function (newValue) {
                if (newValue == undefined || newValue == "" || isNaN(newValue)) {
                    nDecimal = 0;
                } else {
                    nDecimal = newValue;
                }
                var newNumber = getNumber(elm.val(), attrs.decimal);
                ctrl.$setViewValue(formatNumber(newNumber, attrs.decimal));
                ctrl.$render();
            });
            //--modify PAO: 25/05/2018
            //รองรับ touch screen - focus พร้อม key แก้ไขค่า
            elm.bind("focus", function (event) {
                elm.select();
            });
            elm.bind("contextmenu", function (event) {
                elm.select();
                return disabledContextMenu(event);
            });
            elm.bind("touchstart", function (event) {
                elm.select();
                return disabledContextMenu(event);
            });
            elm.bind("touchmove", function (event) {
                elm.select();
                return disabledContextMenu(event);
            });
            elm.bind("touchend", function (event) {
                elm.select();
                return disabledContextMenu(event);
            });
            elm.bind("touchcancel", function (event) {
                elm.select();
                return disabledContextMenu(event);
            });
            //--modify PAO: 21/07/2017
            elm.bind("blur", function (event) {
                var newNumber = parseFloat(elm.val());

                //--max
                if (attrs.max && attrs.max != undefined) {
                    var maxVal = parseFloat(attrs.max);
                    if (newNumber > maxVal) {
                        event.preventDefault();

                        newNumber = getNumber(attrs.max, attrs.decimal);
                        ctrl.$setViewValue(formatNumber(newNumber, attrs.decimal));
                        ctrl.$render();

                        return;
                    }
                }

                //--min
                if (attrs.min && attrs.min != undefined) {
                    var minVal = parseFloat(attrs.min);
                    if (newNumber < minVal) {
                        event.preventDefault();

                        newNumber = getNumber(attrs.min, attrs.decimal);
                        ctrl.$setViewValue(formatNumber(newNumber, attrs.decimal));
                        ctrl.$render();

                        return;
                    }
                }

                ctrl.$viewValue = formatNumber(ctrl.$modelValue, attrs.decimal);
                ctrl.$render();
            });

            elm.bind("keypress", function (event) {
                var dataKey = String.fromCharCode(event.which);
                if (dataKey == "."
                    && elm.val().indexOf(".") >= 0) {
                    return false;
                }

                if (attrs.decimal > 0) {
                    var regex = /^(\d*\.?\d*)$/;
                    return regex.test(dataKey);
                }
                else {
                    var regex = /^\d+$/;
                    return regex.test(dataKey);
                }

                return true;
            });
            //elm.bind('blur', function () {
            //    ctrl.$viewValue = formatNumber(ctrl.$modelValue, attrs.decimal);
            //    ctrl.$render();
            //});
            ctrl.$parsers.unshift(function (viewValue) {
                var testnum = getNumber(viewValue, attrs.decimal);
                ctrl.$setValidity('float', (testnum === 0 ? false : true));
                return (testnum === 0 ? undefined : testnum);
            });
            ctrl.$formatters.unshift(function (modelValue) {
                return modelValue === undefined ? modelValue : formatNumber(modelValue, attrs.decimal);
            });
        }
    };
}]);

app.controller('AppController',
    function ($scope, $http, AppService) {
        $scope.apiUrl = 'http://127.0.0.1:63269/dataservices/';

        angular.element(document).ready(function () {
            
        });
});
